;
;   Package from Bjorn Lambrigtsen
;
;   Sung-Yung Lee
;   June 2002
;
; If colorbar is set, then colobar will be plotted at the bottom of plot
; In that case, if format is also set, the format will be used for scale
;
;   June 2003 : SYLEE		The colobar option was added.
;				The color bar has width of 512 pixels - window should be wider.
;
pro lambrigtsen_map, lat, lon, field, title, max=fmax, min=fmin, $
                     colorbar=colorbar, format=sformat

   @set_color_syl

   numfp = (size(lat))[1]
   numline = (size(lat))[2]

   lim = [ min(lat), min(lon), max(lat), max(lon) ]
   latcenter = lat[numfp/2,numline/2]
   loncenter = lon[numfp/2,numline/2]
;
;  See if the dateline is within the current granule
;
   alon = lon
   if lim[1] lt -150 and lim[3] gt 150 and max([lim[0],lim[2]]) lt 70 then begin
      date_line, lat, alon
      lim = [ min(lat), min(alon), max(lat), max(alon) ]
      loncenter = alon[numfp/2,numline/2]
   endif

;
;  Make room for color bar if necessary
;
   if n_elements(colorbar) eq 0 then begin
      map_set, latcenter, loncenter, /mercator, limit=lim, $
               color=black, title=title
   endif else begin
      map_set, latcenter, loncenter, /mercator, limit=lim, $
               color=black, title=title, $
               position=[0.0,0.1,1.0,0.95]
   endelse

   if n_elements(fmax) eq 0 then begin
      fmax = max(field)
   endif

   if n_elements(fmin) eq 0 then begin
      fmin = min(field)
   endif

   tv, map_patch ( bytscl(field, max=fmax, min=fmin), alon, lat, xstart=x0, ystart=y0 ), x0, y0+0.2

   map_continents, color=green
   map_grid, label=2, color=green

   if n_elements(colorbar) gt 0 then begin
      if n_elements(sformat) eq 0 then sformat='(f4.0)'
      image = bytarr(2,256,30)
      image[0,*,*] = indgen(256,30)
      image[1,*,*] = image[0,*,*]
      image = reform ( image, 512, 30 )
      tv, image, (!d.x_size-512)/2, 20
      xyouts, 0.10, 0.020, string(fmin,format=sformat), $
;              color=black, alignment=0.5, /normal
              alignment=0.5, /normal
      xyouts, 0.30, 0.020, string(0.25*(3*fmin+fmax),format=sformat), $
;              color=black, alignment=0.5, /normal
              alignment=0.5, /normal
      xyouts, 0.50, 0.020, string(0.5*(fmin+fmax),format=sformat), $
;              color=black, alignment=0.5, /normal
              alignment=0.5, /normal
      xyouts, 0.70, 0.020, string(0.25*(fmin+3*fmax),format=sformat), $
;              color=black, alignment=0.5, /normal
              alignment=0.5, /normal
      xyouts, 0.90, 0.020, string(fmax,format=sformat), $
;              color=black, alignment=0.5, /normal
              alignment=0.5, /normal
   endif
end
